import { __makeTemplateObject } from "tslib";
import * as React from 'react';
import Helmet from 'react-helmet';
import { StaticQuery, graphql } from 'gatsby';
/**
 * An SEO component to be used in any component to boost Search Engine Optimization
 * @param title The title of the page
 * @param descrition The pages description
 * @param lang The language of the website. Default set to 'en'
 * @param image The pages main image. If supplied, must supply src, height and width of image. This can be taken from your graphql query
 * @param meta The HTML meta tag
 * @param keywords The pages keywords. Example - blog
 * @param pathname The path of the current page. Example - www.myblog.com/pathname
 */
var SEO = function (_a) {
    var title = _a.title, description = _a.description, _b = _a.lang, lang = _b === void 0 ? 'en' : _b, meta = _a.meta, image = _a.image, keywords = _a.keywords, pathname = _a.pathname;
    return (React.createElement(StaticQuery, { query: detailsQuery, render: function (data) {
            var metaDescription = description || data.site.siteMetadata.description;
            var metaImage = image && image.src ? "" + data.site.siteMetadata.siteUrl + image.src : null;
            var metaUrl = "" + data.site.siteMetadata.siteUrl + pathname;
            return (React.createElement(Helmet, { htmlAttributes: {
                    lang: lang,
                }, title: title, titleTemplate: "%s | " + data.site.siteMetadata.title, meta: [
                    {
                        name: "description",
                        content: metaDescription,
                    },
                    {
                        property: "og:title",
                        content: title,
                    },
                    {
                        property: "og:url",
                        content: metaUrl,
                    },
                    {
                        property: "og:description",
                        content: metaDescription,
                    },
                    {
                        property: "og:type",
                        content: "website",
                    },
                    {
                        name: "twitter:creator",
                        content: "@" + data.site.siteMetadata.social.twitter,
                    },
                    {
                        name: "twitter:title",
                        content: title,
                    },
                    {
                        name: "twitter:description",
                        content: metaDescription,
                    },
                ]
                    .concat(metaImage && image ? [
                    {
                        property: "og:image",
                        content: metaImage
                    },
                    {
                        property: "og:image:alt",
                        content: title,
                    },
                    {
                        property: 'og:image:width',
                        content: image.width
                    },
                    {
                        property: 'og:image:height',
                        content: image.height
                    },
                    {
                        name: "twitter:card",
                        content: "summary_large_image",
                    }
                ] : [
                    {
                        name: "twitter:card",
                        content: "summary",
                    },
                ])
                    .concat(keywords && keywords.length > 0
                    ? {
                        name: "keywords",
                        content: keywords.join(", "),
                    }
                    : [])
                    .concat(meta ? meta : []) }));
        } }));
};
export default SEO;
var detailsQuery = graphql(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  query DefaultSEOQuery {\n    site {\n      siteMetadata {\n        title\n        siteUrl\n        description\n        author\n        social {\n          twitter\n        }\n      }\n    }\n  }\n"], ["\n  query DefaultSEOQuery {\n    site {\n      siteMetadata {\n        title\n        siteUrl\n        description\n        author\n        social {\n          twitter\n        }\n      }\n    }\n  }\n"])));
var templateObject_1;
//# sourceMappingURL=seo.js.map